"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PkgFsBindings = void 0;
const node_1 = require("@zwave-js/core/bindings/fs/node");
const node_path_1 = __importDefault(require("node:path"));
// Ensures that the Z-Wave JS driver is looking for the right files in the right place
// when running inside a `pkg` bundle. In this case, it will resolve its embedded
// configuration dir to the path "/config", but the files reside in "node_modules/@zwave-js/config/config" instead.
const CONFIG_PATH = '/config';
const CONFIG_PATH_IN_PKG = node_path_1.default.join(__dirname, `node_modules/@zwave-js/config/config`);
class PkgFsBindings {
    readFile(path) {
        if (path.startsWith(CONFIG_PATH)) {
            path = path.replace(CONFIG_PATH, CONFIG_PATH_IN_PKG);
        }
        return node_1.fs.readFile(path);
    }
    writeFile(path, data) {
        if (path.startsWith(CONFIG_PATH)) {
            // The pkg assets are readonly
            return;
        }
        return node_1.fs.writeFile(path, data);
    }
    copyFile(source, dest) {
        if (dest.startsWith(CONFIG_PATH)) {
            // The pkg assets are readonly
            return;
        }
        if (source.startsWith(CONFIG_PATH)) {
            source = source.replace(CONFIG_PATH, CONFIG_PATH_IN_PKG);
        }
        return node_1.fs.copyFile(source, dest);
    }
    open(path, flags) {
        if (path.startsWith(CONFIG_PATH) && flags.write) {
            // The pkg assets are readonly
            throw new Error(`${path} is not writable`);
        }
        if (path.startsWith(CONFIG_PATH)) {
            path = path.replace(CONFIG_PATH, CONFIG_PATH_IN_PKG);
        }
        return node_1.fs.open(path, flags);
    }
    readDir(path) {
        if (path.startsWith(CONFIG_PATH)) {
            path = path.replace(CONFIG_PATH, CONFIG_PATH_IN_PKG);
        }
        return node_1.fs.readDir(path);
    }
    stat(path) {
        if (path.startsWith(CONFIG_PATH)) {
            path = path.replace(CONFIG_PATH, CONFIG_PATH_IN_PKG);
        }
        return node_1.fs.stat(path);
    }
    ensureDir(path) {
        if (path.startsWith(CONFIG_PATH)) {
            // The pkg assets are readonly
            return;
        }
        return node_1.fs.ensureDir(path);
    }
    deleteDir(path) {
        if (path.startsWith(CONFIG_PATH)) {
            // The pkg assets are readonly
            return;
        }
        return node_1.fs.deleteDir(path);
    }
    makeTempDir(prefix) {
        return node_1.fs.makeTempDir(prefix);
    }
}
exports.PkgFsBindings = PkgFsBindings;
